<template>
    <StudentLayout>
        <div class="container mt-5">
            <div class="row">
                <!-- Left Column -->
                <div class="col-lg-5 mb-4">
                    <div class="card shadow-sm h-100">
                        <div class="card-body">
                            <!-- Poster -->
                            <img
                                :src="`/storage/uploads/vacancy/${vacancy.poster}`"
                                alt="Poster"
                                class="img-fluid mb-3 rounded"
                            />

                            <!-- Job Info -->
                            <div class="d-flex align-items-center mb-4">
                                <img
                                    :src="`/storage/uploads/company/${vacancy.company.logo}`"
                                    alt="Logo"
                                    class="rounded-circle me-3"
                                    width="60"
                                    height="60"
                                />
                                <div>
                                    <h4 class="mb-1">{{ vacancy.title }}</h4>
                                    <p class="mb-0 text-muted">{{ vacancy.company.name }}</p>
                                </div>
                            </div>

                            <!-- Job Details -->
                            <p class="mb-1"><strong>Lokasi:</strong> {{ vacancy.location }}</p>
                            <p class="mb-1"><strong>Tipe:</strong> {{ vacancy.type }}</p>
                            <p class="mb-1"><strong>Deadline:</strong> {{ formatDate(vacancy.deadline) }}</p>
                            <p class="mb-3"><strong>Total Pelamar:</strong> {{ total_applicants }}</p>

                            <span
                                class="badge"
                                :class="vacancy.is_easy_apply ? 'bg-purple-600' : 'bg-gray-600'"
                            >
                                {{ vacancy.is_easy_apply ? 'Lamaran Mudah' : 'Lamaran Biasa' }}
                            </span>

                            <!-- Apply Button -->
                            <div class="mt-4" style="width: 100% !important;">
                                <a
                                    v-if="!vacancy.is_easy_apply"
                                    :href="vacancy.apply_link"
                                    target="_blank"
                                    class="px-3 py-2 border-1 custom-radius bg-purple-600 w-100 text-white"
                                >
                                    <i class="fas fa-external-link-alt"></i> Lamar Manual
                                </a>
                                <span v-else>
                                    <button
                                        v-if="!has_applied"
                                        class="px-3 py-2 border-1 custom-radius bg-purple-600 w-100 text-white"
                                        @click="showModal = true"
                                    >
                                        Lamar Mudah
                                    </button>
                                    <span v-else class="text-success">Anda sudah melamar pekerjaan ini</span>
                                </span>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-lg-7">
                    <div class="card shadow-sm h-100">
                        <div class="card-body">
                            <h4 class="fw-bold mb-3">Deskripsi Pekerjaan</h4>
                            <div v-html="vacancy.description" class="mb-4"></div>

                            <h4 class="fw-bold mb-3">Kualifikasi</h4>
                            <div v-html="vacancy.qualification" class="mb-4"></div>

                            <h4 class="fw-bold mb-3">Benefit</h4>
                            <div v-html="vacancy.benefits"></div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </StudentLayout>
    <BaseModal
        :is-visible="showModal"
        @close="showModal = false"
        title="Yakin Mau Lamar Nih?"
        class="modal-dialog-centered"
    >
        <template #body>
            <p class="mb-3">
                Sebelum lanjut, pastiin dulu ya profil kamu udah lengkap. Soalnya lamaran ini pakai fitur <strong>Lamar Mudah</strong> —
                jadi langsung kirim pakai data dari halaman <strong>Profile</strong> kamu.
            </p>
            <p class="mb-0">
                Kalau udah siap, tinggal klik lamar dan semoga cocok sama kerjaan ini. Semangat! 🚀
            </p>
        </template>
        <template #footer>
            <button
                class="w-full bg-purple-600 text-white px-4 py-2 custom-radius"
                @click="apply"
            >
                <i class="fas fa-paper-plane"></i> Lamar
            </button>
        </template>
    </BaseModal>


</template>


<script setup>
import StudentLayout from "@/Layouts/StudentLayout.vue";
import BaseModal from "@/Components/Modal/BaseModal.vue";
import {ref} from "vue";
import {useForm} from "@inertiajs/vue3";

const props = defineProps({
    vacancy: Object,
    has_applied: Boolean,
    total_applicants: Number
});
const showModal = ref(false);

function formatDate(dateStr) {
    const options = { day: '2-digit', month: 'long', year: 'numeric' };
    return new Date(dateStr).toLocaleDateString('id-ID', options);
}
const form = useForm();
const apply = () => {
    form.post(`/user/job/${props.vacancy.id}/apply`, {
        onSuccess: () => {
            showModal.value = false;
            form.reset();
        },
        onError: () => {
            showModal.value = false;
        },
    });
};
</script>

<style scoped>
.custom-radius {
    border: none;
    border-radius: 0.5rem;
}
</style>
